Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(211)

Unified Diff: src/factory.h

Issue 2301913002: Rename SloppyBlockWithEvalContextExtension to ContextExtension (Closed)
Patch Set: updates Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/contexts.cc ('k') | src/factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/factory.h
diff --git a/src/factory.h b/src/factory.h
index 840a8bb2c4fb9204d1c3388506581cb144823cdb..da161445b124baf2faf874d34ed6bf3e7de280d5 100644
--- a/src/factory.h
+++ b/src/factory.h
@@ -64,10 +64,9 @@ class Factory final {
// Create a new PrototypeInfo struct.
Handle<PrototypeInfo> NewPrototypeInfo();
- // Create a new SloppyBlockWithEvalContextExtension struct.
- Handle<SloppyBlockWithEvalContextExtension>
- NewSloppyBlockWithEvalContextExtension(Handle<ScopeInfo> scope_info,
- Handle<JSObject> extension);
+ // Create a new ContextExtension struct.
+ Handle<ContextExtension> NewContextExtension(Handle<ScopeInfo> scope_info,
+ Handle<Object> extension);
// Create a pre-tenured empty AccessorPair.
Handle<AccessorPair> NewAccessorPair();
« no previous file with comments | « src/contexts.cc ('k') | src/factory.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698